import React, { useState } from 'react';
import { Container, Typography } from '@mui/material';
import { createTheme, ThemeProvider } from '@mui/material/styles';
import ApiTabs from './ApiTabs';
import { PRESET_BACKENDS } from '../constants';
import { getCookie, setCookie } from '../utils/cookies';

const theme = createTheme();

function App() {
    const [tabValue, setTabValue] = useState(0);
    const [qrInput, setQrInput] = useState('');
    const [userId, setUserId] = useState(getCookie('userId') || '');
    const [response, setResponse] = useState('');
    const [musicData, setMusicData] = useState({
        userId: parseInt(userId) || 0,
        music: {
            musicId: 0,
            level: 0,
            achievement: 0,
            playCount: 0,
            comboStatus: 0,
            syncStatus: 0,
            deluxscoreMax: 0,
            scoreRank: 0
        }
    });
    const [apiBase, setApiBase] = useState(
        localStorage.getItem('apiBase') || PRESET_BACKENDS[0].value
    );
    const [backends, setBackends] = useState([
        ...PRESET_BACKENDS,
        ...JSON.parse(localStorage.getItem('customBackends') || '[]')
    ]);
    const [isDialogOpen, setIsDialogOpen] = useState(false);
    const [newBackend, setNewBackend] = useState({ label: '', value: '' });
    const [snackbarOpen, setSnackbarOpen] = useState(false);
    const [snackbarMessage, setSnackbarMessage] = useState('');

    return (
        <ThemeProvider theme={theme}>
            <div id="root">
                <Container maxWidth="md" sx={{ mt: 4, mb: 4 }}>
                    <ApiTabs
                        tabValue={tabValue}
                        setTabValue={setTabValue}
                        qrInput={qrInput}
                        setQrInput={setQrInput}
                        userId={userId}
                        setUserId={setUserId}
                        response={response}
                        setResponse={setResponse}
                        musicData={musicData}
                        setMusicData={setMusicData}
                        apiBase={apiBase}
                        setApiBase={setApiBase}
                        backends={backends}
                        setBackends={setBackends}
                        isDialogOpen={isDialogOpen}
                        setIsDialogOpen={setIsDialogOpen}
                        newBackend={newBackend}
                        setNewBackend={setNewBackend}
                        snackbarOpen={snackbarOpen}
                        setSnackbarOpen={setSnackbarOpen}
                        snackbarMessage={snackbarMessage}
                        setSnackbarMessage={setSnackbarMessage}
                    />
                </Container>
            </div>
            <footer>
                <Typography variant="body2" color="textSecondary">
                    © 2023 Tsumugiboshi. All rights reserved.
                </Typography>
            </footer>
        </ThemeProvider>
    );
}

export default App;